@@ -1,4 +1,5 @@
 """Landroid Cloud API implementation"""
+
 # pylint: disable=unnecessary-lambda
 from __future__ import annotations
 
@@ -6,6 +7,7 @@ import logging
 import time
 
 from .clouds import CloudType
+from .exceptions import TooManyRequestsError
 from .utils.requests import GET, HEADERS, POST
 
 _LOGGER = logging.getLogger(__name__)
@@ -20,6 +22,7 @@ class LandroidCloudAPI:
         password: str,
         cloud: CloudType.WORX | CloudType.KRESS | CloudType.LANDXCAPE,
         tz: str | None = None,  # pylint: disable=invalid-name
+        token_callback: callable | None = None,
     ) -> None:
         """Initialize a new instance of the API broker.
 
@@ -37,6 +40,7 @@ class LandroidCloudAPI:
         self._api_host = None
         self.api_data = None
         self._tz = tz
+        self._callback = token_callback
 
         self.username = username
         self.password = password
@@ -52,13 +56,18 @@ class LandroidCloudAPI:
             "password": self.password,
         }
 
-        resp = POST(url, request_body, HEADERS())
-        self.access_token = resp["access_token"]
-        self.refresh_token = resp["refresh_token"]
-        now = int(time.time())
-        self._token_expire = now + int(resp["expires_in"])
+        try:
+            resp = POST(url, request_body, HEADERS())
+            self.access_token = resp["access_token"]
+            self.refresh_token = resp["refresh_token"]
+            now = int(time.time())
+            self._token_expire = now + int(resp["expires_in"])
+        except TooManyRequestsError:
+            raise TooManyRequestsError from None
+        except:
+            return
 
-    def update_token(self) -> None:
+    def _update_token(self) -> None:
         """Refresh the tokens."""
         url = f"https://{self.cloud.AUTH_ENDPOINT}/oauth/token"
         request_body = {
@@ -93,21 +102,68 @@ class LandroidCloudAPI:
             return False
         return True
 
+    def check_token(self) -> None:
+        """Check token and refresh if needed."""
+        now = int(time.time())
+
+        if (now + 1800) >= self._token_expire:
+            _LOGGER.debug("Updating access_token")
+            self._update_token()
+            if self._callback:
+                self._callback()
+
     def get_mowers(self) -> str:
         """Get mowers associated with the account.
 
         Returns:
             str: JSON object containing available mowers associated with the account.
         """
+        self.check_token()
+
         mowers = GET(
             f"https://{self.cloud.ENDPOINT}/api/v2/product-items?status=1",
             HEADERS(self.access_token),
         )
         for mower in mowers:
-            mower["firmware_version"] = "{:.2f}".format(mower["firmware_version"])
+            if mower["name"] is None:
+                # Add default name when mower is unnamed
+                mower["name"] = "No Name"
+
+            _LOGGER.debug("Matching models for mower '%s'", mower["name"])
+            model = self.get_model(mower["product_id"])
+            mower["model"] = {
+                "code": model["code"],
+                "friendly_name": str.format(
+                    "{}{}", model["default_name"], model["meters"]
+                ),
+                "model_year": model["product_year"],
+                "cutting_width": model["cutting_width"],
+            }
 
         return mowers
 
+    def get_model(self, product_id: int) -> str | None:
+        """Get model from product_id.
+
+        Returns:
+            str: JSON object containing detailed product information.
+            None: Returned when product_id couldn't be matched to a product.
+        """
+        self.check_token()
+
+        products = GET(
+            f"https://{self.cloud.ENDPOINT}/api/v2/products",
+            HEADERS(self.access_token),
+        )
+
+        product_info = None
+        for product in products:
+            if product["id"] == product_id:
+                product_info = product
+                break
+
+        return product_info
+
     @property
     def data(self) -> str:
         """Return the latest dataset of information and states from the API."""
