@@ -1,4 +1,5 @@
 """Landroid Cloud callback events"""
+
 # pylint: disable=unnecessary-lambda
 from __future__ import annotations
 
@@ -15,6 +16,7 @@ class LandroidEvent(IntEnum):
     MQTT_RATELIMIT = 2
     MQTT_PUBLISH = 3
     LOG = 4
+    API = 5
 
 
 _LOGGER = logging.getLogger("pyworxcloud.events")
@@ -61,7 +63,7 @@ class EventHandler:
             # Event was not set
             return False
 
-        if LandroidEvent.DATA_RECEIVED == event:
+        if LandroidEvent.DATA_RECEIVED == event or LandroidEvent.API == event:
             from .utils.devices import DeviceHandler
 
             if not check_syntax(kwargs, ["name"], str) or not check_syntax(
