@@ -1,5 +1,9 @@
 """Battery information."""
+
+from __future__ import annotations
+
 from enum import IntEnum
+from typing import Any
 
 from .landroid_class import LDict
 
@@ -24,7 +28,9 @@ CHARGE_MAP = {
 class Battery(LDict):
     """Battery information."""
 
-    def __init__(self, indata: list = None, cycle_info=None) -> None:
+    def __init__(
+        self, indata: list | None = None, cycle_info: Any | None = None
+    ) -> None:
         """Initialize a battery object."""
         super().__init__()
 
@@ -39,6 +45,18 @@ class Battery(LDict):
                 "reset_time": None,
             }
 
+        if not "temperature" in self:
+            self["temperature"] = None
+
+        if not "voltage" in self:
+            self["voltage"] = None
+
+        if not "percent" in self:
+            self["percent"] = None
+
+        if not "charging" in self:
+            self["charging"] = None
+
         if indata:
             self.set_data(indata)
             self._update_cycles()
@@ -94,11 +112,15 @@ class Battery(LDict):
             self["cycles"].update(
                 {
                     "reset_at": int(indata.battery_charge_cycles_reset),
-                    "reset_time": string_to_time(
-                        indata.battery_charge_cycles_reset_at, indata.time_zone
-                    )
-                    if not isinstance(indata.battery_charge_cycles_reset_at, type(None))
-                    else None,
+                    "reset_time": (
+                        string_to_time(
+                            indata.battery_charge_cycles_reset_at, indata.time_zone
+                        )
+                        if not isinstance(
+                            indata.battery_charge_cycles_reset_at, type(None)
+                        )
+                        else None
+                    ),
                 }
             )
         else:
