@@ -1,4 +1,5 @@
 """Blade information."""
+
 from __future__ import annotations
 
 from typing import Any
@@ -24,7 +25,7 @@ class Blades(LDict):
             # Total time with blades on in minutes
             self["total_on"] = (
                 int(data["blade_work_time"])
-                if not isinstance(data["blade_work_time_reset"], type(None))
+                if not isinstance(data["blade_work_time"], type(None))
                 else None
             )
         else:
@@ -43,7 +44,7 @@ class Blades(LDict):
         if "blade_work_time_reset_at" in data:
             # Blade time reset time and date
             self["reset_time"] = (
-                string_to_time(data["blade_work_time_reset_at"], data["time_zone"])
+                string_to_time(data["blade_work_time_reset_at"], None)
                 if not isinstance(data["blade_work_time_reset_at"], type(None))
                 else None
             )
