@@ -1,4 +1,5 @@
 """States handler."""
+
 from __future__ import annotations
 
 from enum import IntEnum
@@ -16,16 +17,21 @@ STATE_TO_DESCRIPTION = {
     5: "searching home",
     6: "searching wire",
     7: "mowing",
-    8: "lifted",
+    8: "mowing",
     9: "trapped",
     10: "blade blocked",
     11: "debug",
     12: "remote control",
+    13: "digital fence escape",
     30: "going home",
     31: "zoning",
     32: "cutting edge",
     33: "searching area",
     34: "pause",
+    103: "searching zone",
+    104: "searching home",
+    110: "border crossing",
+    111: "exploring lawn",
 }
 
 # Valid error states
@@ -53,6 +59,22 @@ ERROR_TO_DESCRIPTION = {
     19: "battery trunk open timeout",
     20: "wire sync",
     21: "msg num",
+    100: "charging station docking error",
+    101: "hbi error",
+    102: "ota error",
+    103: "map error",
+    104: "excessive slope",
+    105: "unreachable zone",
+    106: "unreachable charging station",
+    108: "insufficient sensor data",
+    109: "training start disallowed",
+    110: "camera error",
+    111: "mapping exploration required",
+    112: "mapping exploration failed",
+    113: "rfid reader error",
+    114: "headlight error",
+    115: "missing charging station",
+    116: "blade height adjustment blocked",
 }
 
 
@@ -67,10 +89,15 @@ class States(LDict):
     """States class handler."""
 
     def update(self, new_id: int) -> None:
-        self["id"] = new_id
-        self["description"] = self.__descriptor[self["id"]]
+        """Update the dataset."""
+        try:
+            self["id"] = new_id
+            self["description"] = self.__descriptor[self["id"]]
+        except KeyError:
+            self["description"] = self.__descriptor[-1]
 
     def __init__(self, statetype: StateType = StateType.STATUS) -> dict:
+        """Initialize the dataset."""
         super().__init__()
 
         self.__descriptor = STATE_TO_DESCRIPTION
